==> linshare-1.4.6-src.tar.bz2: src/main/java/org/linagora/linshare/core/business/service/impl/DomainPolicyBusinessServiceImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2013 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2013. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.business.service.impl;

import java.util.List;

import org.linagora.linshare.core.business.service.DomainPolicyBusinessService;
import org.linagora.linshare.core.domain.entities.AbstractDomain;
import org.linagora.linshare.core.domain.entities.DomainPolicy;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.repository.AbstractDomainRepository;
import org.linagora.linshare.core.repository.DomainPolicyRepository;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DomainPolicyBusinessServiceImpl implements DomainPolicyBusinessService{

    private static final Logger logger = LoggerFactory.getLogger(DomainPolicyBusinessServiceImpl.class);
	
	private final DomainPolicyRepository domainPolicyRepository;
	private final AbstractDomainRepository abstractDomainRepository;
	
	public DomainPolicyBusinessServiceImpl(DomainPolicyRepository domainPolicyRepository,AbstractDomainRepository abstractDomainRepository)
	{
		super();
		this.domainPolicyRepository=domainPolicyRepository;
		this.abstractDomainRepository=abstractDomainRepository;
	}
	
    @Override
    public DomainPolicy createDomainPolicy(DomainPolicy domainPolicy) throws BusinessException{
        return domainPolicyRepository.create(domainPolicy);
    }
	
    @Override
    public void updateDomainPolicy(DomainPolicy domainPolicy) throws BusinessException {
    	DomainPolicy policy = domainPolicyRepository.findById(domainPolicy.getIdentifier());
        domainPolicyRepository.update(policy);
    }
    
    
    @Override
    public void deletePolicy(String policyToDelete) throws BusinessException {
        if (!policyIsDeletable(policyToDelete)) {
            throw new BusinessException("Cannot delete policy because still used by domains");
        }
        DomainPolicy policy = retrieveDomainPolicy(policyToDelete);
        if(policy == null) {
        	logger.error("Policy not found: " + policyToDelete);
        } else {
            logger.debug("delete policy: " + policyToDelete);
            domainPolicyRepository.delete(policy);
        }
    }
    
    @Override
    public boolean policyIsDeletable(String policyToDelete) {
    	List<AbstractDomain> list = abstractDomainRepository.findAll();
        boolean used = false;
        for (AbstractDomain domain : list) {
            if (domain.getPolicy().getIdentifier().equals(policyToDelete)) {
                used = true;
                break;
            }
        }
        return (!used);
    }
    
	@Override
	public DomainPolicy retrieveDomainPolicy(String identifier){
		return domainPolicyRepository.findById(identifier);
	}
	
	@Override
	public List<DomainPolicy> findAllDomainPolicy()  {
		return domainPolicyRepository.findAll();
	}
	
	@Override
	public List<String> findAllIdentifiers() {
		return domainPolicyRepository.findAllIdentifiers();
	}
	
}

==> linshare-1.5.6-src.tar.bz2: src/main/java/org/linagora/linshare/core/business/service/impl/DomainPolicyBusinessServiceImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2014 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2014. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.business.service.impl;

import java.util.List;

import org.linagora.linshare.core.business.service.DomainPolicyBusinessService;
import org.linagora.linshare.core.domain.entities.AbstractDomain;
import org.linagora.linshare.core.domain.entities.DomainPolicy;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.repository.AbstractDomainRepository;
import org.linagora.linshare.core.repository.DomainPolicyRepository;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DomainPolicyBusinessServiceImpl implements
		DomainPolicyBusinessService {

	private static final Logger logger = LoggerFactory
			.getLogger(DomainPolicyBusinessServiceImpl.class);

	private final DomainPolicyRepository domainPolicyRepository;
	private final AbstractDomainRepository abstractDomainRepository;

	public DomainPolicyBusinessServiceImpl(
			DomainPolicyRepository domainPolicyRepository,
			AbstractDomainRepository abstractDomainRepository) {
		super();
		this.domainPolicyRepository = domainPolicyRepository;
		this.abstractDomainRepository = abstractDomainRepository;
	}

	@Override
	public DomainPolicy createDomainPolicy(DomainPolicy domainPolicy)
			throws BusinessException {
		return domainPolicyRepository.create(domainPolicy);
	}

	@Override
	public void updateDomainPolicy(DomainPolicy domainPolicy)
			throws BusinessException {
		domainPolicyRepository.update(domainPolicy);
	}

	@Override
	public void deletePolicy(String identifier) throws BusinessException {
		if (!policyIsDeletable(identifier)) {
			throw new BusinessException(
					"Cannot delete policy because still used by domains");
		}
		DomainPolicy policy = retrieveDomainPolicy(identifier);
		if (policy == null) {
			logger.error("Policy not found: " + identifier);
		} else {
			logger.debug("delete policy: " + identifier);
			domainPolicyRepository.delete(policy);
		}
	}

	@Override
	public boolean policyIsDeletable(String identifier) {
		for (AbstractDomain domain : abstractDomainRepository.findAll()) {
			if (domain.getPolicy().getIdentifier().equals(identifier)) {
				return false;
			}
		}
		return true;
	}

	@Override
	public DomainPolicy retrieveDomainPolicy(String identifier) {
		return domainPolicyRepository.findById(identifier);
	}

	@Override
	public List<DomainPolicy> findAllDomainPolicy() {
		return domainPolicyRepository.findAll();
	}

	@Override
	public List<String> findAllIdentifiers() {
		return domainPolicyRepository.findAllIdentifiers();
	}

}
